@@ -33,6 +33,8 @@
 #include <libgit2-glib/ggit-tree.h>
 #include <libgit2-glib/ggit-branch.h>
 #include <libgit2-glib/ggit-blob-output-stream.h>
+#include <libgit2-glib/ggit-checkout-options.h>
+#include <libgit2-glib/ggit-note.h>
 
 G_BEGIN_DECLS
 
@@ -97,12 +99,16 @@ GgitRef            *ggit_repository_lookup_reference  (GgitRepository        *re
 GgitRef            *ggit_repository_create_reference  (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GgitOId               *oid,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitRef            *ggit_repository_create_symbolic_reference
                                                       (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        const gchar           *target,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitBlobOutputStream *
@@ -136,7 +142,7 @@ GgitOId            *ggit_repository_create_commit     (GgitRepository        *re
                                                        gint                   parent_count,
                                                        GError               **error);
 
-GgitOId            *ggit_repository_create_commit_from_oids (
+GgitOId            *ggit_repository_create_commit_from_ids (
                                                        GgitRepository        *repository,
                                                        const gchar           *update_ref,
                                                        GgitSignature         *author,
@@ -169,14 +175,32 @@ GgitOId            *ggit_repository_create_tag_lightweight (
                                                        GgitCreateFlags        flags,
                                                        GError               **error);
 
+GgitOId            *ggit_repository_create_tag_annotation (
+                                                       GgitRepository        *repository,
+                                                       const gchar           *tag_name,
+                                                       GgitObject            *target,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *message,
+                                                       GError               **error);
+
+gboolean            ggit_repository_delete_tag        (GgitRepository        *repository,
+                                                       const gchar           *name,
+                                                       GError               **error);
+
+gboolean            ggit_repository_tag_foreach       (GgitRepository        *repository,
+                                                       GgitTagCallback        callback,
+                                                       gpointer               user_data,
+                                                       GError               **error);
+
+GgitTreeBuilder    *ggit_repository_create_tree_builder (
+                                                       GgitRepository        *repository,
+                                                       GError               **error);
+
 GgitTreeBuilder    *ggit_repository_create_tree_builder_from_tree (
                                                        GgitRepository        *repository,
                                                        GgitTree              *tree,
                                                        GError               **error);
 
-GgitTreeBuilder    *ggit_repository_create_tree_builder (
-                                                       GgitRepository        *repository);
-
 GgitIndexEntry     *ggit_repository_create_index_entry_for_file (
                                                        GgitRepository        *repository,
                                                        GFile                 *file,
@@ -192,14 +216,20 @@ GgitIndexEntry     *ggit_repository_create_index_entry_for_path (
 gchar             **ggit_repository_list_tags         (GgitRepository        *repository,
                                                        GError               **error);
 
+gchar             **ggit_repository_list_tags_match   (GgitRepository        *repository,
+                                                       const gchar           *pattern,
+                                                       GError               **error);
+
 GgitBranch         *ggit_repository_create_branch     (GgitRepository        *repository,
                                                        const gchar           *branch_name,
                                                        GgitObject            *target,
                                                        GgitCreateFlags        flags,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitBranchEnumerator *ggit_repository_enumerate_branches (GgitRepository        *repository,
-                                                          GgitBranchType         list_flags,
+                                                          GgitBranchType         list_type,
                                                           GError               **error);
 
 GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *repository,
@@ -207,7 +237,7 @@ GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *re
                                                        GgitBranchType         branch_type,
                                                        GError               **error);
 
-GgitRemote         *ggit_repository_get_remote        (GgitRepository        *repository,
+GgitRemote         *ggit_repository_lookup_remote     (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GError               **error);
 
@@ -277,6 +307,14 @@ gboolean            ggit_repository_submodule_foreach  (GgitRepository
 void                ggit_repository_reset              (GgitRepository          *repository,
                                                         GgitObject              *target,
                                                         GgitResetType            reset_type,
+                                                        GgitCheckoutOptions     *checkout_options,
+                                                        GgitSignature           *signature,
+                                                        const gchar             *log_message,
+                                                        GError                 **error);
+
+void                ggit_repository_reset_default      (GgitRepository          *repository,
+                                                        GgitObject              *target,
+                                                        const gchar * const     *pathspecs,
                                                         GError                 **error);
 
 GgitObject         *ggit_repository_revparse          (GgitRepository        *repository,
@@ -305,6 +343,11 @@ void                ggit_repository_get_ahead_behind  (GgitRepository        *re
                                                        gsize                 *behind,
                                                        GError               **error);
 
+gboolean            ggit_repository_get_descendant_of (GgitRepository        *repository,
+                                                       GgitOId               *commit,
+                                                       GgitOId               *ancestor,
+                                                       GError               **error);
+
 GgitBlame          *ggit_repository_blame_file        (GgitRepository        *repository,
                                                        GFile                 *file,
                                                        GgitBlameOptions      *blame_options,
@@ -316,6 +359,67 @@ const gchar        *ggit_repository_get_attribute     (GgitRepository
                                                        GgitAttributeCheckFlags   flags,
                                                        GError                  **error);
 
+gboolean            ggit_repository_checkout_head     (GgitRepository           *repository,
+                                                       GgitCheckoutOptions      *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_checkout_index    (GgitRepository           *repository,
+                                                       GgitIndex                *index,
+                                                       GgitCheckoutOptions      *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_checkout_tree     (GgitRepository           *repository,
+                                                       GgitObject               *tree,
+                                                       GgitCheckoutOptions      *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_revert            (GgitRepository           *repository,
+                                                       GgitCommit               *commit,
+                                                       GgitRevertOptions        *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_cherry_pick       (GgitRepository           *repository,
+                                                       GgitCommit               *commit,
+                                                       GgitCherryPickOptions    *options,
+                                                       GError                  **error);
+
+GgitIndex          *ggit_repository_cherry_pick_commit (GgitRepository           *repository,
+                                                        GgitCommit               *commit,
+                                                        GgitCommit               *our_commit,
+                                                        guint                     mainline,
+                                                        GgitMergeOptions         *merge_options,
+                                                        GError                  **error);
+
+const gchar        *ggit_repository_get_default_notes_ref (GgitRepository           *repository,
+                                                           GError                  **error);
+
+GgitOId            *ggit_repository_create_note        (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitSignature           *author,
+                                                        GgitSignature           *committer,
+                                                        GgitOId                 *id,
+                                                        const gchar             *note,
+                                                        gboolean                 force,
+                                                        GError                 **error);
+
+gboolean            ggit_repository_remove_note        (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitSignature           *author,
+                                                        GgitSignature           *committer,
+                                                        GgitOId                 *id,
+                                                        GError                 **error);
+
+GgitNote           *ggit_repository_read_note          (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitOId                 *id,
+                                                        GError                 **error);
+
+gboolean            ggit_repository_note_foreach       (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitNoteCallback         callback,
+                                                        gpointer                 user_data,
+                                                        GError                 **error);
+
 G_END_DECLS
 
 #endif /* __GGIT_REPOSITORY_H__ */
